@@ -7,7 +7,7 @@ except ImportError:
     require_package('CleverCSS')
 
 from strange_case.registry import Registry
-from strange_case.nodes import FileNode
+from strange_case.nodes import AssetNode
 
 clevercss_compiler = clevercss.convert
 
@@ -35,25 +35,27 @@ class CleverCssExtension(jinja2.ext.Extension):
         return clevercss_compiler(caller()).strip()
 
 
-class CleverCssNode(FileNode):
+class CleverCssNode(AssetNode):
     """
     Converts a .ccss file into css
     """
     def generate_file(self, site, source_path, target_path):
-        ccss_content = open(source_path, 'r').read()
-        css_content = clevercss_compiler(ccss_content)
-        with open(self.target_path) as f:
-            f.write(css_content)
+        if self['skip']:
+            print 'Skipping %s' % target_path
+        if not self['skip']:
+            ccss_content = open(source_path, 'r').read()
+            css_content = clevercss_compiler(ccss_content)
+            with open(target_path, 'w') as f:
+                f.write(css_content)
+        self.files_tracked.append(source_path)
         self.files_written.append(target_path)
 
-        super(CleverCssNode, self).generate(site)
-
 
 def processor(config, source_path, target_path):
-    if config['target_name'][-4:] == 'ccss':
-        config['target_name'][-4:] = 'css'
-    if config['target_name'][-9:] == 'clevercss':
-        config['target_name'][-9:] = 'css'
+    if config['target_name'].endswith('ccss'):
+        config['target_name'] = config['target_name'][:-4] + 'css'
+    if config['target_name'].endswith('clevercss'):
+        config['target_name'] = config['target_name'][:-9] + 'css'
 
     ccss_node = CleverCssNode(config, source_path, target_path)
     return (ccss_node,)
